@@ -1,11 +1,4 @@
-from __future__ import absolute_import
-from builtins import str
-from builtins import range
-from builtins import object
-try:
-    from collections import OrderedDict  # 2.7
-except ImportError:
-    from sqlalchemy.util import OrderedDict
+from sqlalchemy.util import OrderedDict
 
 from ckan.lib import helpers as h
 from logging import getLogger
